##  Visualizing Tech Standards Usage and Governance Compliance
SAP LeanIX provides insights into your organization's technology standards for SAP BTP usage, broken down by areas like app development and automation. Creating a BTP Radar in SAP LeanIX helps determine what percentage of your SAP-related integrations leverage SAP BTP. Additionally, it allows you to assess whether you are adhering to tech standards when implementing extensions, ensuring compliance and governance across your projects.
Example reports:
![SAP BTP Radar Showing All BTP PaaS Services Grouped by Category and Rated Based on Assessment](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27564b4e7a441014af26f3bc84722ddc_LowRes.png)
SAP BTP Radar Showing All BTP PaaS Services Grouped by Category and Rated Based on Assessment
![Clean Core Assessment Showing the SAP BTP Status of the Applications](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274d10c67a441014a3e89bb907ddf83e_LowRes.png)
Clean Core Assessment Showing the SAP BTP Status of the Applications
![Interface Landscape Report Showing Interfaces Running on SAP Integration Suite \(BTP\) and SAP Process Orchestration](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275416317a441014a7f6d5e193870772_LowRes.png)
Interface Landscape Report Showing Interfaces Running on SAP Integration Suite (BTP) and SAP Process Orchestration
